"""Commandline interface to extract reno notes in machine-readable itemized form."""

import argparse
import json
import logging
import sys

from reno_structured_output import Config, collect_notes

parser = argparse.ArgumentParser(
    prog="reno-structured-output",
    description="Provide 'reno' release notes in machine-readable, itemized form.",
)

parser.add_argument(
    "reporoot",
    nargs="?",
    default="./",
    help="root of the git repository",
)
parser.add_argument(
    "-d",
    "--rel-notes-dir",
    help="location of release notes YAML files (relative to reporoot)",
)
parser.add_argument("-v", "--verbose", action="count", default=0)
parser.add_argument("-q", "--quieter", action="count", default=0)


def main() -> int:
    args = parser.parse_args()
    logging.basicConfig(
        level=dict(
            enumerate((logging.ERROR, logging.WARNING, logging.INFO), start=-1)
        ).get(args.verbose - args.quieter, logging.DEBUG)
    )
    print(args, file=sys.stderr)
    config = Config(args.reporoot, relnotesdir=args.rel_notes_dir)
    print(json.dumps(collect_notes(config), indent=2, sort_keys=False))
    return 0



from collections import defaultdict
from pathlib import Path

import yaml
from reno.config import Config
from reno.scanner import Scanner


def collect_notes(conf: Config | None = None) -> dict:
    conf = conf or Config("./")
    with Scanner(conf) as scnr:
        relnotes = scnr.get_notes_by_version()

    reporoot = Path(conf.reporoot)

    relnotes_content: dict = defaultdict(lambda: defaultdict(list))
    for version, version_details in relnotes.items():
        version_files = [x[0] for x in version_details]
        for f in version_files:
            version_file_content = yaml.load(
                (reporoot / f).read_text(), Loader=yaml.SafeLoader
            )
            for category, notes in version_file_content.items():
                if isinstance(notes, str):
                    relnotes_content[version][category].append(notes)
                else:
                    relnotes_content[version][category].extend(notes)

    return relnotes_content



from reno_structured_output import collect_notes


def test_collect_notes_as_python_structure():
    notes = collect_notes()
    assert isinstance(notes, dict)
    assert "v0.0.2" in list(notes.keys())
